@@ -1,6 +1,12 @@
 
 levelsPrepF <- function(data, at, original_data){
 
+  # drop any unused factor levels #
+  
+  original_data[] <- lapply(original_data, function(x) if(is.factor(x)) droplevels(x) else x)
+  
+  # get the start and end data #
+  
     for(j in names(at)){
 
       if(is.numeric(data[[j]]) & (is.character(original_data[[j]]) | is.factor(original_data[[j]]))){
