@@ -27,13 +27,13 @@ test_that("make sure bayesPredsF is working properly", {
   expect_no_error(bayesPredsF(logitModel, at=list(educ=c(0, 12)), hdi_interval=F, n_draws=500))
   expect_no_error(bayesPredsF(logitModel, at=list(educ=c(0, 12)), at_means=T, n_draws=500))
   expect_no_error(bayesPredsF(logitModel, at=list(educ=c(0, 12)), hdi_interval=F, at_means=T, n_draws=500))
-  expect_no_error(bayesPredsF(logitModel, at=list(educ=c(0, 12), dist=c(10, 20), arsenic=c(2,3), assoc=c('Y')), n_draws=500))
+  expect_no_error(bayesPredsF(logitModel, at=list(educ=c(0, 12), dist=c(10, 20), arsenic=c(2,3), assoc=c('Y')), n_draws=500, data_slice=100))
   
   expect_no_warning(bayesPredsF(logitModel2, at=list(educ=c(0, 12)), n_draws=500))
   expect_no_warning(bayesPredsF(logitModel, at=list(educ=c(0, 12)), n_draws=500))
   expect_no_warning(bayesPredsF(logitModel, at=list(educ=c(0, 12)), hdi_interval=F, n_draws=500))
   expect_no_warning(bayesPredsF(logitModel, at=list(educ=c(0, 12)), at_means=T, n_draws=500))
-  expect_no_warning(bayesPredsF(logitModel, at=list(educ=c(0, 12)), hdi_interval=F, at_means=T, n_draws=500))
+  expect_no_warning(bayesPredsF(logitModel, at=list(educ=c(0, 12)), hdi_interval=F, at_means=T, n_draws=500, data_slice=100))
   
 })
 
